@@ -12,6 +12,13 @@ class TestMTLCountersHelper(Metal.NSObject):
 
 
 class TestMTLCounters(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(Metal.MTLCounterSampleBufferError)
+
+    def test_typed_enum(self):
+        self.assertIsTypedEnum(Metal.MTLCommonCounter, str)
+        self.assertIsTypedEnum(Metal.MTLCommonCounterSet, str)
+
     def test_constants(self):
         self.assertEqual(Metal.MTLCounterErrorValue, 0xFFFFFFFFFFFFFFFF)
 
